"""
    BasisTheory Vault API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import basistheory
from basistheory.model.reactor_formula_configuration import ReactorFormulaConfiguration
from basistheory.model.reactor_formula_request_parameter import ReactorFormulaRequestParameter
globals()['ReactorFormulaConfiguration'] = ReactorFormulaConfiguration
globals()['ReactorFormulaRequestParameter'] = ReactorFormulaRequestParameter
from basistheory.model.reactor_formula import ReactorFormula


class TestReactorFormula(unittest.TestCase):
    """ReactorFormula unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReactorFormula(self):
        """Test ReactorFormula"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ReactorFormula()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
