"""
    Basis Theory API

    ## Getting Started * Sign-in to [Basis Theory](https://basistheory.com) and go to [Applications](https://portal.basistheory.com/applications) * Create a Basis Theory Private Application * All permissions should be selected * Paste the API Key into the `BT-API-KEY` variable  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import unittest

import basistheory
from basistheory.api.three_ds_api import ThreeDSApi  # noqa: E501


class TestThreeDSApi(unittest.TestCase):
    """ThreeDSApi unit test stubs"""

    def setUp(self):
        self.api = ThreeDSApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_call_3ds_sessions_id_get(self):
        """Test case for call_3ds_sessions_id_get

        """
        pass

    def test_three_ds_authenticate_session(self):
        """Test case for three_ds_authenticate_session

        """
        pass

    def test_three_ds_get_challenge_result(self):
        """Test case for three_ds_get_challenge_result

        """
        pass


if __name__ == '__main__':
    unittest.main()
